searchData={"items":[{"type":"module","title":"Tablet","doc":"A tiny tabular data renderer\n\nThis module renders tabular data as text for output to the console or any\nwhere else. Give it data in either of the following common tabular data\nshapes:\n\n```\n# List of matching maps (atom or string keys)\ndata = [\n  %{\"id\" => 1, \"name\" => \"Puck\"},\n  %{\"id\" => 2, \"name\" => \"Nick Bottom\"}\n]\n\n# List of matching key-value lists\ndata = [\n  [{\"id\", 1}, {\"name\", \"Puck\"}],\n  [{\"id\", 2}, {\"name\", \"Nick Bottom\"}]\n]\n```\n\nThen call `Tablet.puts/2`:\n\n```\nTablet.puts(data)\n#=> id  name\n#=> 1   Puck\n#=> 2   Nick Bottom\n```\n\nWhile this shows a table with minimal styling, it's possible to create\nfancier tables with colors, borders and more.\n\nHere are some of Tablet's features:\n\n* `Kino.DataTable`-inspired API for ease of switching between Livebook and console output\n* Automatic column sizing\n* Multi-column wrapping for tables with many rows and few columns\n* Data eliding for long strings\n* Customizable data formatting and styling\n* Unicode support for emojis and other wide characters\n* `t:IO.ANSI.ansidata/0` throughout\n* Small. No runtime dependencies.\n\nWhile seemingly an implementation detail, Tablet's use of `t:IO.ANSI.ansidata/0`\nallows a lot of flexibility in adding color and style to rendering. See `IO.ANSI`\nand the section below to learn more about this cool feature if you haven't used\nit before.","ref":"Tablet.html"},{"type":"module","title":"Example - Tablet","doc":"Here's a more involved example:\n\n```\niex> data = [\n...>   %{planet: \"Mercury\", orbital_period: 88},\n...>   %{planet: \"Venus\", orbital_period: 224.701},\n...>   %{planet: \"Earth\", orbital_period: 365.256},\n...>   %{planet: \"Mars\", orbital_period: 686.971}\n...> ]\niex> formatter = fn\n...>   :__header__, :planet -> {:ok, \"Planet\"}\n...>   :__header__, :orbital_period -> {:ok, \"Orbital Period\"}\n...>   :orbital_period, value -> {:ok, \"#{value} days\"}\n...>   _, _ -> :default\n...> end\niex> Tablet.render(data, keys: [:planet, :orbital_period], formatter: formatter)\n...>    |> IO.ANSI.format(false)\n...>    |> IO.chardata_to_string()\n\"Planet   Orbital Period\n\" <>\n\"Mercury  88 days       \n\" <>\n\"Venus    224.701 days  \n\" <>\n\"Earth    365.256 days  \n\" <>\n\"Mars     686.971 days  \n\"\n```\n\nNote that normally you'd call `IO.ANSI.format/2` without passing `false` to\nget colorized output and also call `IO.puts/2` to write to a terminal.","ref":"Tablet.html#module-example"},{"type":"module","title":"Data formatting and column headers - Tablet","doc":"Tablet naively converts data values and constructs column headers to\n`t:IO.ANSI.ansidata/0`. This may not be what you want. To customize this,\npass a 2-arity function using the `:formatter` option. That function takes\nthe key and value as arguments and should return `{:ok, ansidata}`. The\nspecial key `:__header__` is passed when constructing header row. Return\n`:default` to use the default conversion.","ref":"Tablet.html#module-data-formatting-and-column-headers"},{"type":"module","title":"Styling - Tablet","doc":"Various table output styles are supported by supplying a `:style` function.\nThe following are included:\n\n* `compact/3` - a minimal table style with underlined headers (default)\n* `markdown/3` - GitHub-flavored markdown table style","ref":"Tablet.html#module-styling"},{"type":"module","title":"Ansidata - Tablet","doc":"Tablet takes advantage of `t:IO.ANSI.ansidata/0` everywhere. This makes it\neasy to apply styling, colorization, and other transformations. However,\nit can be hard to read. It's highly recommended to either call `simplify/1` to\nsimplify the output for review or to call `IO.ANSI.format/2` and then\n`IO.puts/2` to print it.\n\nIn a nutshell, `t:IO.ANSI.ansidata/0` lets you create lists of strings to\nprint and intermix atoms like `:red` or `:blue` to indicate where ANSI escape\nsequences should be inserted if supported. Tablet actually doesn't know what\nany of the atoms means and passes them through. Elixir's `IO.ANSI` module\ndoes all of the work. If fact, if you find `IO.ANSI` too limited, then you\ncould use an alternative like [bunt](https://hex.pm/packages/bunt) and\ninclude atoms like `:chartreuse` which its formatter will understand.","ref":"Tablet.html#module-ansidata"},{"type":"type","title":"Tablet.column_width/0","doc":"Column width values\n\nColumn widths may be passed via the `:column_widths` options. The following\nvalues may also be specified:\n\n* `:default` - use the `:default_column_width`. This is the same as not\n  specifying the column width\n* `:minimum` - make the column minimally fit the widest data element\n* `:expand` - expand the column so that the table is as wide as the console\n\nWhen multiple keys have the `:expand`, they'll be allocated equal space.","ref":"Tablet.html#t:column_width/0"},{"type":"function","title":"Tablet.compute_column_widths/2","doc":"Compute column widths\n\nThis function is useful if you need to render more than one table\nwith the same keys and want column widths to stay the same. It\ntakes the same options as `render/2`. It returns a fully resolved\nversion of the `:column_widths` option that can be passed to\nfuture calls to `render/2` and `puts/2`.","ref":"Tablet.html#compute_column_widths/2"},{"type":"type","title":"Tablet.data/0","doc":"Row-oriented data","ref":"Tablet.html#t:data/0"},{"type":"function","title":"Tablet.fit/3","doc":"Fit ansidata into the specified number of characters\n\nThis function is useful for styling output to fit data into a cell.","ref":"Tablet.html#fit/3"},{"type":"type","title":"Tablet.formatter/0","doc":"Data formatter callback function\n\nThis function is used for conversion of tabular data to `t:IO.ANSI.ansidata/0`.\nThe special key `:__header__` is passed when formatting the column titles.\n\nThe callback should return `{:ok, ansidata}` or `:default`.","ref":"Tablet.html#t:formatter/0"},{"type":"type","title":"Tablet.justification/0","doc":"Justification for padding ansidata","ref":"Tablet.html#t:justification/0"},{"type":"type","title":"Tablet.key/0","doc":"An atom or string key that identifies a data column","ref":"Tablet.html#t:key/0"},{"type":"type","title":"Tablet.line_context/0","doc":"Line rendering context\n\nThe context is a simple map with fields that Tablet adds for conveying the\nsection and row number that it's on. Row numbers start at 0. For normally\nrendered tables (`:wrap_across` unset or set to 1), the row number\ncorresponds to row in the input data. For multi-column tables, the row\nis the left-most row in the group of rows that are rendered together.\n\nThe `:slice` field indicates which line is being rendered within the row. For\nsingle line rows, it will be 0. For multi-line rows, it will be 0 for the first\nline, then 1, etc.\n\nNote that the line rendering function can output many lines of text per one input\nline. This is useful for adding borders.","ref":"Tablet.html#t:line_context/0"},{"type":"type","title":"Tablet.line_renderer/0","doc":"Row rendering callback function\n\nTablet makes calls to the styling function for each line in the table\nstarting with the header, then the rows (0 to N-1), and finally the footer.\nThe second parameter is the `t:line_context/0` with position details.\n\nThe third parameter is a list of `t:IO.ANSI.ansidata/0` values. When\nrendering multi-column tables (`:wrap_across` set to greater than 1), each\nitem in the list corresponds to a set of columns. If your styling function\ndoesn't care about multi-column tables, then call `List.flatten/1` on the\nparameter.\n\nThe return value is always `t:IO.ANSI.ansidata/0`. It should contain a final\nnew line since `Tablet` doesn't add anything.  Multiple lines can be returned\nif borders or more room for text is needed.\n\nWhen writing styling functions, it's recommended to pattern matching on the\ncontext.  Most of the time, you'll just need to know whether you're in the\n`:header` section or dealing with data rows. The context contains enough\ninformation to do more complicated things like match on even or odd lines and\nmore if needed.","ref":"Tablet.html#t:line_renderer/0"},{"type":"type","title":"Tablet.matching_key_value_list/0","doc":"One row of data represented as a list of column ID, data tuples","ref":"Tablet.html#t:matching_key_value_list/0"},{"type":"type","title":"Tablet.matching_map/0","doc":"One row of data represented in a map","ref":"Tablet.html#t:matching_map/0"},{"type":"function","title":"Tablet.puts/2","doc":"Print a table to the console\n\nCall this to quickly print tabular data to the console.\n\nThis supports all of the options from `render/2`.\n\nAdditional options:\n* `:ansi_enabled?` - force ANSI output. If unset, the terminal setting is used.","ref":"Tablet.html#puts/2"},{"type":"function","title":"Tablet.render/2","doc":"Render a table as `t:IO.ANSI.ansidata/0`\n\nThis formats tabular data and returns it in a form that can be run through\n`IO.ANSI.format/2` for expansion of ANSI escape codes and then written to\nan IO device.\n\nOptions:\n\n* `:column_widths` - a map of keys to their desired column widths. See `t:column_width/0`.\n* `:data` - tabular data\n* `:default_column_width` - default column width in characters\n* `:formatter` - if passing non-ansidata, supply a function to apply custom formatting\n* `:keys` - a list of keys to include in the table for each record. The order is reflected in the rendered table. Optional\n* `:name` - the name or table title. This can be any `t:IO.ANSI.ansidata/0` value. Not used by default style.\n* `:style` - see `t:style/0` for details on styling tables\n* `:total_width` - the total width of the table if any of the `:column_widths` is `:expand`. Defaults to the console width if needed.\n* `:wrap_across` - the number of columns to wrap across in multi-column mode","ref":"Tablet.html#render/2"},{"type":"function","title":"Tablet.simplify/1","doc":"Convenience function for simplifying ansidata\n\nThis is useful when debugging or checking output for unit tests. It flattens\nthe list, combines strings, and removes redundant ANSI codes.","ref":"Tablet.html#simplify/1"},{"type":"type","title":"Tablet.style_function/0","doc":"Style function callback\n\nTablet calls this function after processing user options. The style\nfunction can modify anything in Tablet's state or wrap functions or\ndo whatever it wants to adjust the output.\n\nOptions are passed via the `:style_options` option which is included in the\nparameter.\n\nFor most styles, the callback should set at least:\n\n* `:line_renderer` - a function that processes data for one line to the final output\n* `:style_padding` - horizontal padding map.\n  * `:edge` - number of characters added on the left and right edges of the table\n  * `:cell` - number of characters added between two cells\n  * `:multi_column` - number of characters added between multi-column border cells","ref":"Tablet.html#t:style_function/0"},{"type":"type","title":"Tablet.t/0","doc":"Table renderer state\n\nFields:\n* `:data` - data rows\n* `:column_widths` - a map of keys to their desired column widths. See `t:column_width/0`.\n* `:keys` - a list of keys to include in the table for each record. The order is reflected in the rendered table. Optional\n* `:default_row_height` - number of rows or `:minimum` to set based on cell contents. Defaults to `:minimum`\n* `:default_column_width` - column width to use when unspecified in `:column_widths`. Defaults to `:minimum`\n* `:formatter` - a function to format the data in the table. The default is to convert everything to strings.\n* `:line_renderer` - a function that processes data for one line to the final output\n* `:name` - the name or table title. This can be any `t:IO.ANSI.ansidata/0` value.\n* `:style` - one of the built-in styles or a function to style the table. The default is `:compact`.\n* `:style_options` - styling options. See style documentation for details.\n* `:style_padding` - horizontal padding map\n  * `:edge` - number of characters added on the left and right edges of the table\n  * `:cell` - number of characters added between two cells\n  * `:multi_column` - number of characters added between multi-column border cells\n* `:total_width` - the width of the console for use when expanding columns. The default is 0 to autodetect.\n* `:wrap_across` - the number of columns to wrap across in multi-column mode. The default is 1.","ref":"Tablet.html#t:t/0"},{"type":"function","title":"Tablet.visual_size/1","doc":"Calculate the size of ansidata when rendered\n\nThe return value is the width and height.","ref":"Tablet.html#visual_size/1"},{"type":"function","title":"Examples - Tablet.visual_size/1","doc":"```\niex> ansidata = [\"Hello, \", :red, \"world\", :default_color, \"!\"]\niex> Tablet.visual_size(ansidata)\n{13, 1}\n```","ref":"Tablet.html#visual_size/1-examples"},{"type":"module","title":"Tablet.Styles","doc":"Built-in tabular data rendering styles","ref":"Tablet.Styles.html"},{"type":"function","title":"Tablet.Styles.box/1","doc":"Box style\n\nRender tabular data with borders drawn from the ASCII character set. This\nshould render everywhere.\n\nTo use, pass `style: :box` to `Tablet.puts/2` or `Tablet.render/2`.","ref":"Tablet.Styles.html#box/1"},{"type":"function","title":"Tablet.Styles.compact/1","doc":"Compact style\n\nThis style produces compact output by only underlining the header and adding\nwhitespace around data. It is the default style.","ref":"Tablet.Styles.html#compact/1"},{"type":"function","title":"Tablet.Styles.generic_box/1","doc":"Generic box style\n\nRender tabular data with whatever characters you want for borders. This is\nused by the Box and Unicode Box styles. It's configurable via the `:style_options`\noption as can be seen in the Box and Unicode Box implementations. Users can\nalso call this directly by passing `style: :generic_box` and `style_options: [border: ...]`.\n\nOptions:\n* `:border` - a map with the  following fields:\n  * `:h` and `:v` - the horizontal and vertical characters\n  * `:ul` and `:ur` - upper left and upper right corners\n  * `:uc` - intersection of the horizontal top border with a vertical (looks like a T)\n  * `:ll` and `:lr` - lower left and lower right corners\n  * `:lc` - analogous to `:uc` except on the Nick Bottom border\n  * `:l` and `:r` - left and right side characters with horizontal lines towards the interior\n  * `:c` - interior horizontal and vertical intersection","ref":"Tablet.Styles.html#generic_box/1"},{"type":"function","title":"Tablet.Styles.ledger/1","doc":"Ledger table style\n\nRender tabular data as rows that alternate colors.\n\nTo use, pass `style: :ledger` to `Tablet.puts/2` or `Tablet.render/2`.","ref":"Tablet.Styles.html#ledger/1"},{"type":"function","title":"Tablet.Styles.markdown/1","doc":"Markdown table style\n\nRender tabular data as a GitHub-flavored markdown table. Multi-line cells\nhave their newlines replaced with ` ` tags.\n\nPass `style: :markdown` to `Tablet.puts/2` or `Tablet.render/2` to use.","ref":"Tablet.Styles.html#markdown/1"},{"type":"function","title":"Tablet.Styles.unicode_box/1","doc":"Unicode box style\n\nRender tabular data with borders drawn with Unicode characters. This is a nicer\ntake on the `:box` style.\n\nTo use, pass `style: :unicode_box` to `Tablet.puts/2` or `Tablet.render/2`.","ref":"Tablet.Styles.html#unicode_box/1"},{"type":"extras","title":"Tablet","doc":"# Tablet\n\n[![Hex version](https://img.shields.io/hexpm/v/tablet.svg \"Hex version\")](https://hex.pm/packages/tablet)\n[![API docs](https://img.shields.io/hexpm/v/tablet.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/tablet/Tablet.html)\n[![CircleCI](https://dl.circleci.com/status-badge/img/gh/fhunleth/tablet/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/fhunleth/tablet/tree/main)\n[![Coverage Status](https://coveralls.io/repos/github/fhunleth/tablet/badge.svg)](https://coveralls.io/github/fhunleth/tablet)\n[![REUSE status](https://api.reuse.software/badge/github.com/fhunleth/tablet)](https://api.reuse.software/info/github.com/fhunleth/tablet)\n\nTablet renders tabular data as text for output to the console or any\nwhere else. Give it data in either of the following common tabular data\nshapes:\n\n```elixir\n# List of matching maps (atom or string keys)\ndata = [\n  %{\"id\" => 1, \"name\" => \"Puck\"},\n  %{\"id\" => 2, \"name\" => \"Nick Bottom\"}\n]\n\n# List of matching key-value lists\ndata = [\n  [{\"id\", 1}, {\"name\", \"Puck\"}],\n  [{\"id\", 2}, {\"name\", \"Nick Bottom\"}]\n]\n```\n\nThen call `Tablet.puts/2`:\n\n```elixir\nTablet.puts(data)\n#=> id  name\n#=> 1   Puck\n#=> 2   Nick Bottom\n```\n\nWhile this shows a table with minimal styling, it's possible to create\nfancier tables with colors, borders and more.\n\nHere are some of Tablet's features:\n\n* [`Kino.DataTable`](https://hexdocs.pm/kino/Kino.DataTable.html)-inspired API for ease of switching between Livebook and console output\n* Small. No runtime dependencies. Intentionally minimal feature scope.\n* Emoji and CJK character width calculations w/o external dependencies\n* Multi-column wrapping for tables with many rows and few columns\n* Built-in [styles](gallery.md) and optional callback interface for customization\n* Supports [`IO.ANSI.ansidata`](https://hexdocs.pm/elixir/IO.ANSI.html#format/1) throughout for color, italics, and more in cells and styling\n* Supports [`usage_rules`](https://hex.pm/packages/usage_rules) for helping LLMs make beautiful tables\n\n[![Run in Livebook](https://livebook.dev/badge/v1/pink.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Ffhunleth%2Ftablet%2Fblob%2Fmain%2Fnotebooks%2Ftablet.livemd)\n\nIf you're comparing tabular data rendering libraries, Tablet sacrifices\nflexibility in how individual cells can be rendered for small size. Color\nselection, text alignment, border characters, etc. are all grouped into the\nstyle. If you're happy with the built-in styles, rendering may be a one-liner.\nSee [`table_rex`](https://hex.pm/packages/table_rex) for another option that has\nmore flexibility in cell layout.","ref":"readme.html"},{"type":"extras","title":"Example - Tablet","doc":"Here's a more involved example:\n\n```elixir\niex> data = [\n...>   %{planet: \"Mercury\", orbital_period: 88},\n...>   %{planet: \"Venus\", orbital_period: 224.701},\n...>   %{planet: \"Earth\", orbital_period: 365.256},\n...>   %{planet: \"Mars\", orbital_period: 686.971}\n...> ]\niex> formatter = fn\n...>   :__header__, :planet -> {:ok, \"Planet\"}\n...>   :__header__, :orbital_period -> {:ok, \"Orbital Period\"}\n...>   :orbital_period, value -> {:ok, \"\\#{value} days\"}\n...>   _, _ -> :default\n...> end\niex> Tablet.render(data, keys: [:planet, :orbital_period], formatter: formatter)\n...>    |> IO.ANSI.format(false)\n...>    |> IO.chardata_to_string()\n\"Planet   Orbital Period\\n\" <>\n\"Mercury  88 days       \\n\" <>\n\"Venus    224.701 days  \\n\" <>\n\"Earth    365.256 days  \\n\" <>\n\"Mars     686.971 days  \\n\"\n```\n\nNote that normally you'd call `IO.ANSI.format/2` without passing `false` to\nget colorized output and also call `IO.puts/2` to write to a terminal.","ref":"readme.html#example"},{"type":"extras","title":"Data formatting and column headers - Tablet","doc":"Tablet naively converts data values and constructs column headers to\n`t:IO.ANSI.ansidata/0`. This may not be what you want. To customize this,\npass a 2-arity function using the `:formatter` option. That function takes\nthe key and value as arguments and should return `{:ok, ansidata}`. The special key\n`:__header__` is passed when constructing header row. Return `:default`\nto use the default conversion.","ref":"readme.html#data-formatting-and-column-headers"},{"type":"extras","title":"Styling - Tablet","doc":"Various table output styles are supported by passing an atom or 1-arity\nfunction to the  `:style` parameter.\n\nSee the [Style Gallery](gallery.md) for the built-in styles.\n\nIf the built-in styles don't suffice, it is possible for you to add your own by\ncreating a function of the type `t:Tablet.style_function/0`. Due to the desire\nto minimize the main `Tablet` code as much as possible, only a few helper\nfunctions are available. See the built-in styles for code examples.","ref":"readme.html#styling"},{"type":"extras","title":"Ansidata - Tablet","doc":"Tablet takes advantage of `t:IO.ANSI.ansidata/0` everywhere. This makes it\neasy to apply styling, colorization, and other transformations. However,\nit can be hard to read. It's highly recommended to either call `simplify/1` to\nsimplify the output for review or to call `IO.ANSI.format/2` and then\n`IO.puts/2` to print it.\n\nIn a nutshell, `t:IO.ANSI.ansidata/0` lets you create lists of strings to\nprint and intermix atoms like `:red` or `:blue` to indicate where ANSI escape\nsequences should be inserted if supported. Tablet actually doesn't know what\nany of the atoms means and passes them through. Elixir's `IO.ANSI` module\ndoes all of the work. If fact, if you find `IO.ANSI` too limited, then you\ncould use an alternative like [bunt](https://hex.pm/packages/bunt) and\ninclude atoms like `:chartreuse` which its formatter will understand.","ref":"readme.html#ansidata"},{"type":"extras","title":"Notes and acknowledgments - Tablet","doc":"1. The implementation is no longer simple. Multi-line cell support really put\n   it over the edge, but I still hope to figure out how to simplify it again.\n\n2. Thanks to Claude 3.7 for creating tons of example uses of Tablet so I could\n   see how it looked. It drove me to `usage-rules.md` due to its epic butchering\n   of ansidata.\n\n3. Thanks to the Rust\n   [tabled](https://github.com/zhiburt/tabled/tree/master/tabled) project for\n   showing what's possible.","ref":"readme.html#notes-and-acknowledgments"},{"type":"extras","title":"Style Gallery","doc":"# Style Gallery\n\n1. [Box](#box)\n1. [Compact](#compact)\n1. [Ledger](#ledger)\n1. [Markdown](#markdown)\n1. [Unicode Box](#unicode-box)","ref":"gallery.html"},{"type":"extras","title":"Box - Style Gallery","doc":"Render tabular data with borders drawn from the ASCII character set. This\nshould render everywhere.\n\nTo use, pass `style: :box` to `Tablet.puts/2` or `Tablet.render/2`.\n\n![box screenshot](assets/box.png)","ref":"gallery.html#box"},{"type":"extras","title":"Compact - Style Gallery","doc":"This style produces compact output by only underlining the header and adding\nwhitespace around data. It is the default style.\n\n![compact screenshot](assets/compact.png)","ref":"gallery.html#compact"},{"type":"extras","title":"Ledger - Style Gallery","doc":"Render tabular data as rows that alternate colors.\n\nTo use, pass `style: :ledger` to `Tablet.puts/2` or `Tablet.render/2`.\n\n![ledger screenshot](assets/ledger.png)","ref":"gallery.html#ledger"},{"type":"extras","title":"Markdown - Style Gallery","doc":"Render tabular data as a GitHub-flavored markdown table. Multi-line cells\nhave their newlines replaced with ` ` tags.\n\nPass `style: :markdown` to `Tablet.puts/2` or `Tablet.render/2` to use.\n\n![markdown screenshot](assets/markdown.png)","ref":"gallery.html#markdown"},{"type":"extras","title":"Unicode Box - Style Gallery","doc":"Render tabular data with borders drawn with Unicode characters. This is a nicer\ntake on the `:box` style.\n\nTo use, pass `style: :unicode_box` to `Tablet.puts/2` or `Tablet.render/2`.\n\n![unicode_box screenshot](assets/unicode_box.png)","ref":"gallery.html#unicode-box"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.3.1 - Changelog","doc":"* Changes\n  * Fix padding of Erlang strings","ref":"changelog.html#v0-3-1"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"* Backwards incompatible changes\n  * Styling functions can modify pretty much everything and layer themselves on\n    other styles. If you created a custom style, check out the built-in styles\n    for how to update.\n\n* New features\n  * Support multi-line cell data. This works in all built-in styles and includes\n    color support. The `:markdown` style will convert new lines to ` ` tags\n    to render as you'd expect.\n  * Add `usage-rules.md` to help LLMs especially with ansidata. See\n    [usage_rules](https://hex.pm/packages/usage_rules).\n\n* Changes\n  * Match `Kino.DataFrame` semantics better with the default formatter. This\n    notably improves date and time formatting.\n  * Improve width calculations so that automatically expanding columns better\n    match the terminal width\n  * Significantly improve test coverage","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"* Backwards incompatible changes\n  * Replace `left_trim_pad/2` with more generic `fit_to_width/3` that supports\n    left, right, and center alignment in cells for styling.  This only affects\n    custom styles.\n\n* Changes\n  * Render titles using the `:name` option\n  * Add `compute_column_widths/2` to pre-calculate column widths so that they\n    can be used across repeated renderings of a table. This prevents column\n    widths changing each time.\n  * Replace ANSI resets with more specific codes to avoid affecting globally\n    applied ANSI features.\n  * Fix several edge cases when trimming cell contents\n  * Fix width calculations for Japanese text by embedding a very simple port of\n    Markus Kuhn's `wcwidth` implementation","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release to hex.","ref":"changelog.html#v0-1-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}